@@ -1,9 +1,11 @@
 # Copyright Avraham Adler (c) 2023
 # SPDX-License-Identifier: MPL-2.0+
 
-tol <- 1e-7
+tol <- sqrt(.Machine$double.eps)
+
 opts <- list(maxiter = 100L, miniter = 10L, conviter = 10L,
-             showProgress = FALSE, convRatio = 1.000000001, tol = 1e-14)
+             showProgress = FALSE, convRatio = 1.000000001, tol = 1e-14,
+             ztol = .Machine$double.eps)
 # Test ratMat
 x <- c(-0.4, 0.1, 0.3, 0.4)
 E <- 0.5
@@ -23,7 +25,7 @@ expect_identical(minimaxApprox:::ratMat(x, E, y, 2L, 2L, FALSE), control)
 fn <- function(x) x ^ 2 + 2 * x + 3
 x <- seq(0, 2, length.out = 4)
 control <- c(3, 2, 1)
-RR <- minimaxApprox:::ratCoeffs(x, 0, fn, 2L, 0L, TRUE)
+RR <- minimaxApprox:::ratCoeffs(x, 0, fn, 2L, 0L, TRUE, 0, 2, opts$ztol)
 expect_equal(RR$a, control, tolerance = tol)
 expect_identical(RR$b, 1)
 expect_equal(RR$E, 0, tolerance = tol)
