@@ -1,9 +1,11 @@
 # Copyright Avraham Adler (c) 2023
 # SPDX-License-Identifier: MPL-2.0+
 
-tol <- 1e-7
+tol <- sqrt(.Machine$double.eps)
+
 opts <- list(maxiter = 100L, miniter = 10L, conviter = 10L,
-             showProgress = FALSE, convRatio = 1.000000001, tol = 1e-14)
+             showProgress = FALSE, convRatio = 1.000000001, tol = 1e-14,
+             ztol = .Machine$double.eps)
 
 # Test fC
 expect_identical(minimaxApprox:::fC(1.234567, f = "e"), "1.234567e+00")
@@ -47,7 +49,6 @@ controlF <- function(x) {
 x <- 3
 expect_equal(minimaxApprox:::polyCalc(x, coeffs), controlF(x), tolerance = tol)
 x <- 5
-control2 <- 2 + 3.2 * x + 4.6 * x ^ 2 - 9.7 * x ^ 3 + 0.1 * x ^ 4
 expect_equal(minimaxApprox:::polyCalc(x, coeffs), controlF(x), tolerance = tol)
 x <- 1e-14
 expect_equal(minimaxApprox:::polyCalc(x, coeffs), controlF(x), tolerance = tol)
@@ -88,19 +89,20 @@ expect_equal(minimaxApprox:::remErr(x, RR, fn, FALSE), control, tolerance = tol)
 fn <- function(x) exp(x) - 1
 x <- minimaxApprox:::chebNodes(3, 0, 1)
 ## Polynomial
-QQ <- minimaxApprox:::polyCoeffs(x, function(x) expm1(x), TRUE)
+QQ <- minimaxApprox:::polyCoeffs(x, function(x) expm1(x), TRUE, 0, 1, opts$ztol)
 control <- minimaxApprox:::findRoots(x, QQ, function(x) expm1(x), TRUE)
-PP <- minimaxApprox:::polyCoeffs(x, fn, TRUE)
+PP <- minimaxApprox:::polyCoeffs(x, fn, TRUE, 0, 1, opts$ztol)
 r <- minimaxApprox:::findRoots(x, PP, fn, TRUE)
 ## Need weaker tolerance here since functions are not exactly the same
-expect_equal(r, control, tolerance = 1.2e-5)
+expect_equal(r, control, tolerance = 1e-7)
 ## Rational
-QQ <- minimaxApprox:::ratCoeffs(x, 0, function(x) expm1(x), 1L, 0L, TRUE)
+QQ <- minimaxApprox:::ratCoeffs(x, 0, function(x) expm1(x), 1L, 0L, TRUE, 0, 1,
+                                opts$ztol)
 control <- minimaxApprox:::findRoots(x, QQ, function(x) expm1(x), TRUE)
-RR <- minimaxApprox:::ratCoeffs(x, 0, fn, 1L, 0L, TRUE)
+RR <- minimaxApprox:::ratCoeffs(x, 0, fn, 1L, 0L, TRUE, 0, 1, opts$ztol)
 r <- minimaxApprox:::findRoots(x, RR, fn, TRUE)
 ## Need weaker tolerance here since functions are not exactly the same
-expect_equal(r, control, tolerance = 1.2e-5)
+expect_equal(r, control, tolerance = 1e-7)
 ## Test error trap with contrived example
 ## Polynomial
 mmA <- minimaxApprox(exp, 1, 2, 4L)
@@ -114,23 +116,26 @@ expect_identical(r, 1.2)
 # Test switchX
 # Assuming function is correct, replicate a previous result.
 ## Polynomial
-control <- c(-1, 0.10264319209405934, 0.33737347892134784, 0.62760323678827878,
-             0.88067525674799318, 1)
+control <- c(-1, 0.10264791208519766, 0.33735881337846646, 0.62760501759598053,
+             0.88066205512236839, 1)
 fn <- function(x) sin(x) + cos(x)
 x <- minimaxApprox:::chebNodes(6, 0, 1)
-PP <- minimaxApprox:::polyCoeffs(x, fn, FALSE)
+PP <- minimaxApprox:::polyCoeffs(x, fn, FALSE, 0, 1, opts$ztol)
 r <- minimaxApprox:::findRoots(x, PP, fn, FALSE)
 x <- minimaxApprox:::switchX(r, -1, 1, PP, fn, FALSE)
-expect_equal(x, control, tolerance = tol)
+# Need weaker tolerance here due to different build platforms
+expect_equal(x, control, tolerance = 3.5e-5)
+
 ## Rational
-control <- c(-1, -0.67069346181121259, -6.9988944598198266e-08,
-             0.67069355653042717, 1)
+control <- c(-1, -0.6706726462230721, -2.8931353340360859e-14,
+             0.67067262060160282, 1)
 fn <- function(x) ifelse(abs(x) < 1e-20, 1, sin(x) / x)
 x <- minimaxApprox:::chebNodes(5, -1, 1)
-RR <- minimaxApprox:::ratCoeffs(x, 0, fn, 2L, 1L, FALSE)
+RR <- minimaxApprox:::ratCoeffs(x, 0, fn, 2L, 1L, FALSE, -1, 1, opts$ztol)
 r <- minimaxApprox:::findRoots(x, RR, fn, FALSE)
 x <- minimaxApprox:::switchX(r, -1, 1, RR, fn, FALSE)
-expect_equal(x, control, tolerance = 3e-7) # GitHub macOS complains otherwise
+# Need weaker tolerance here due to different build platforms
+expect_equal(x, control, tolerance = 3.5e-5)
 
 ## Contrive no extremum examples for maximization and minimization
 R <- list(a = 0, b = 1)
